Test selectWindow
open | ../tests/html/test_select_window.html |
click | popupPage |
waitForPopUp | myPopupWindow | 5000
selectWindow | myPopupWindow |
verifyTitle | Select Window Popup |

Check page transitions in popup window

quick loading page

setTimeout | 5000 |
clickAndWait | link=Click to load new page |
verifyTitle | Reload Page |

slow loading page

setTimeout | 30000 |
clickAndWait | link=Click here |
verifyTitle | Slow Loading Page |
close |  |
selectWindow | null |